#
# spec file for package python-python-ptrace
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%define pyversion 0.9.8
%define cversion 0.6.1
%if "%{flavor}" == ""
%define pkgname python-ptrace
%define pkgversion %{pyversion}
%bcond_with test
%endif
%if "%{flavor}" == "cptrace"
%define pkgname cptrace
%define pkgversion %{cversion}
%bcond_with test
%endif
%if "%{flavor}" == "test"
%define pkgname python-ptrace-test
%define pkgversion %{pyversion}+%{cversion}
%bcond_without test
ExcludeArch:    %arm
%endif

Name:           python-%{pkgname}
Version:        %{pkgversion}
Release:        1.6
Summary:        Python binding for ptrace
License:        GPL-2.0-only
Group:          Development/Languages/Python
URL:            https://github.com/vstinner/python-ptrace
Source:         https://github.com/haypo/python-ptrace/archive/%{pyversion}.tar.gz#/python-ptrace-%{pyversion}.tar.gz
# PATCH-FIX-UPSTREAM - Add python-ptrace-pr81-importlib.patch gh#vstinner/python-ptrace#81
Patch0:         https://github.com/vstinner/python-ptrace/pull/81.patch#/python-ptrace-pr81-importlib.patch
# PATCH-FIX-UPSTREAM - Add python-ptrace-pr83-importlib.patch gh#vstinner/python-ptrace#83
Patch1:         https://github.com/vstinner/python-ptrace/pull/83.patch#/python-ptrace-pr83-importlib.patch
%if "%{flavor}" == "cptrace"
BuildRequires:  %{python_module devel}
%else
BuildArch:      noarch
Recommends:     python-cptrace = %{cversion}
%endif
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires(post): update-alternatives
Requires(postun): update-alternatives
%if %{with test}
BuildRequires:  %{python_module cptrace = %{cversion}}
BuildRequires:  %{python_module python-ptrace = %{pyversion}}
%endif
%python_subpackages

%description
python-ptrace is a debugger using ptrace written in Python.

%prep
%autosetup -p1 -n python-ptrace-%{pyversion}
sed -i 's/\x0D$//' doc/*.rst
chmod 0644 examples/*.py

%build
%if !%{with test}
%if "%{flavor}" == "cptrace"
mv setup.py setup_python-ptrace.py
mv setup_cptrace.py setup.py
%endif
%pyproject_wheel
%endif

%install
%if !%{with test}
%pyproject_install
%if "%{flavor}" == "cptrace"
%python_expand %fdupes %{buildroot}%{$python_sitearch}
%else
%python_clone -a %{buildroot}%{_bindir}/gdb.py
%python_clone -a %{buildroot}%{_bindir}/strace.py
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif
%endif

%if %{with test}
%check
%python_exec runtests.py -v
%endif

%if !%{with test}
%if "%{flavor}" == ""
%post
%python_install_alternative strace.py
%python_install_alternative gdb.py

%postun
%python_uninstall_alternative strace.py
%python_uninstall_alternative gdb.py

%files %{python_files}
%license COPYING
%doc README.rst
%doc doc/* examples
%python_alternative %{_bindir}/gdb.py
%python_alternative %{_bindir}/strace.py
%{python_sitelib}/ptrace/
%{python_sitelib}/python_ptrace-%{pkgversion}.dist-info
%endif

%if "%{flavor}" == "cptrace"
%files %{python_files}
%license COPYING
%doc README.rst
%{python_sitearch}/cptrace*.so
%{python_sitearch}/cptrace-%{pkgversion}.dist-info
%endif
%endif

%changelog
* Sun Mar  3 2024 Ben Greiner <code@bnavigator.de>
- Update to 0.9.8
  * Added Arm 64bit (AArch64) support.
  * Implemented ``PTRACE_GETREGSET`` and ``PTRACE_SETREGSET``
    required on AArch64 and available on Linux.
  * Issue #66: Fix ``SIGTRAP|0x80`` or ``SIGTRAP`` wait in
    syscall_state.exit  (``PTRACE_O_TRACESYSGOOD``).
- Build PEP517 wheels separately in multibuild
- Add patchtes for Python 3.12:
  * python-ptrace-pr81-importlib.patch gh#vstinner/python-ptrace#81
  * python-ptrace-pr83-importlib.patch gh#vstinner/python-ptrace#83
- Remove upstreamed patch:
  * add-aarch64-support.patch
* Wed Jan 13 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Backport patch to add aarch64 support:
  * add-aarch64-support.patch
* Wed Jan 13 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 0.9.7:
  * Add missing module to install directives
- Update to 0.9.6:
  * Drop Python 2.7 support. six dependency is no longer needed
  * Add close_fds and pass_fds to createChild() function
  * Enhance strace.py output for open flags and open optional parameters
  * Add support for PowerPC 64-bit (ppc64)
* Thu Sep 10 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- aarch64 is not yet supported, so exclude it
  See: https://github.com/vstinner/python-ptrace/issues/57
* Wed Aug  5 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 0.9.5
  * Fix readProcessMappings() for device id on 3 digits. Patch by Cat Stevens.
  * Drop Python 2 support.
* Tue Sep 10 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.9.4:
  * Issue #36: Fix detaching from process object created without is_attached=True
  * The project now requires the six module.
* Tue Sep 19 2017 mimi.vx@gmail.com
- update to 0.9.3
  * Fix test_strace.py: tolerate the openat() syscall
* Wed Jun 28 2017 jengelh@inai.de
- Trim description, rectify errors.
* Mon Jun 26 2017 mimi.vx@gmail.com
- use simpler macros to build C parts and run tests
* Sun Jun 25 2017 mimi.vx@gmail.com
- update to 0.9.2
- move to singlespec
  * Fix strace.py when tracing multiple processes: use the correct process.
* Thu Oct 27 2016 mimi.vx@gmail.com
- initial packaging
